@@ -1,9 +1,7 @@
 """HTML/js representation of Pandas dataframes"""
 
-import io
 import json
 import logging
-import os
 import uuid
 import warnings
 
@@ -15,20 +13,14 @@ from IPython.core.display import HTML, Javascript, display
 import itables.options as opt
 
 from .downsample import downsample
+from .utils import read_package_file
 
 logging.basicConfig()
 logger = logging.getLogger(__name__)
 
-_DATATABLE_LOADED = False
 _ORIGINAL_DATAFRAME_REPR_HTML = pd.DataFrame._repr_html_
 
 
-def read_package_file(*path):
-    current_path = os.path.dirname(__file__)
-    with io.open(os.path.join(current_path, *path), encoding="utf-8") as fp:
-        return fp.read()
-
-
 def init_notebook_mode(all_interactive=False):
     """Load the datatables.net library and the corresponding css, and if desired (all_interactive=True),
     activate the datatables representation for all the Pandas DataFrames and Series.
@@ -44,18 +36,9 @@ def init_notebook_mode(all_interactive=False):
         if hasattr(pd.Series, "_repr_html_"):
             del pd.Series._repr_html_
 
-    load_datatables(skip_if_already_loaded=False)
-
-
-def load_datatables(skip_if_already_loaded=True):
-    global _DATATABLE_LOADED
-    if _DATATABLE_LOADED and skip_if_already_loaded:
-        return
-
+    # TODO remove this when require.js is not used any more, see #51
     display(Javascript(read_package_file("require_config.js")))
 
-    _DATATABLE_LOADED = True
-
 
 def _formatted_values(df):
     """Return the table content as a list of lists for DataTables"""
@@ -79,7 +62,7 @@ def _formatted_values(df):
     return formatted_df.values.tolist()
 
 
-def _table_header(df, table_id, show_index, classes):
+def _table_header(df, table_id, show_index, classes, style):
     """This function returns the HTML table header. Rows are not included."""
     thead = ""
     if show_index:
@@ -88,10 +71,15 @@ def _table_header(df, table_id, show_index, classes):
     for column in df.columns:
         thead += f"<th>{column}</th>"
 
-    loading = "<td>Loading... (need <a href=https://github.com/mwouts/itables/#table-not-loading>help</a>?)</td>"
+    loading = "<td>Loading... (need <a href=https://mwouts.github.io/itables/troubleshooting.html>help</a>?)</td>"
     tbody = f"<tr>{loading}</tr>"
 
-    return f'<table id="{table_id}" class="{classes}"><thead>{thead}</thead><tbody>{tbody}</tbody></table>'
+    if style:
+        style = f'style="{style}"'
+    else:
+        style = ""
+
+    return f'<table id="{table_id}" class="{classes}"{style}><thead>{thead}</thead><tbody>{tbody}</tbody></table>'
 
 
 def eval_functions_dumps(obj):
@@ -134,6 +122,7 @@ def _datatables_repr_(df=None, tableId=None, **kwargs):
 
     # These options are used here, not in DataTable
     classes = kwargs.pop("classes")
+    style = kwargs.pop("style")
     showIndex = kwargs.pop("showIndex")
     maxBytes = kwargs.pop("maxBytes", 0)
     maxRows = kwargs.pop("maxRows", 0)
@@ -165,7 +154,7 @@ def _datatables_repr_(df=None, tableId=None, **kwargs):
     if not showIndex:
         df = df.set_index(pd.RangeIndex(len(df.index)))
 
-    table_header = _table_header(df, tableId, showIndex, classes)
+    table_header = _table_header(df, tableId, showIndex, classes, style)
     output = replace_value(
         output,
         '<table id="table_id"><thead><tr><th>A</th></tr></thead></table>',
@@ -215,5 +204,4 @@ def _any_function(value):
 def show(df=None, **kwargs):
     """Show a dataframe"""
     html = _datatables_repr_(df, **kwargs)
-    load_datatables(skip_if_already_loaded=True)
     display(HTML(html))
